mailRe: r4526 - /1.3/test_suite/unit_tests/_prompt/test_minimisation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by Sebastien Morin on January 09, 2008 - 17:29:
Hi,

Do you want me to change it in every places in the 1.3 line ?


Séb



Edward d'Auvergne wrote:
Hi,

This is a change that's been in my head for quite a number of years.
The 'print_flag' corresponds to the quantity of information printed,
and so 'verbosity' is a much better description.  This is change
supposed to be system-wide, but for the consistency testing code it
only appears once.  It's not used by anything but should probably be
changed in the 'calculate' function.

Regards,

Edward



On Jan 9, 2008 5:02 PM, Sebastien Morin <sebastien.morin.1@xxxxxxxxx> wrote:
  
Hi,

I saw a few commits concerning the change of 'print_flag' to 'verbosity'.

Is this change for everywhere or simply in a few special cases like for
the minimise() functions ?

Cheers


Séb






edward@xxxxxxxxxxxxx wrote:
    
Author: bugman
Date: Wed Jan  9 11:25:14 2008
New Revision: 4526

URL: http://svn.gna.org/viewcvs/relax?rev=4526&view=rev
Log:
Changed all references to 'print_flag' to 'verbosity' in the user function arg unit tests.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_minimisation.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_minimisation.py
URL: http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_minimisation.py?rev=4526&r1=4525&r2=4526&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_minimisation.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_minimisation.py Wed Jan  9 11:25:14 2008
@@ -41,8 +41,8 @@
     minimisation_fns = Minimisation(fake_relax.fake_instance())


-    def test_calc_argfail_print_flag(self):
-        """The print_flag arg test of the calc() user function."""
+    def test_calc_argfail_verbosity(self):
+        """The verbosity arg test of the calc() user function."""

         # Loop over the data types.
         for data in DATA_TYPES:
@@ -51,7 +51,7 @@
                 continue

             # The argument test.
-            self.assertRaises(RelaxIntError, self.minimisation_fns.calc, print_flag=data[1])
+            self.assertRaises(RelaxIntError, self.minimisation_fns.calc, verbosity=data[1])


     def test_grid_search_argfail_lower(self):
@@ -126,8 +126,8 @@
             self.assertRaises(RelaxBinError, self.minimisation_fns.grid_search, constraints=data[1])


-    def test_grid_search_argfail_print_flag(self):
-        """The print_flag arg test of the grid_search() user function."""
+    def test_grid_search_argfail_verbosity(self):
+        """The verbosity arg test of the grid_search() user function."""

         # Loop over the data types.
         for data in DATA_TYPES:
@@ -136,7 +136,7 @@
                 continue

             # The argument test.
-            self.assertRaises(RelaxIntError, self.minimisation_fns.grid_search, print_flag=data[1])
+            self.assertRaises(RelaxIntError, self.minimisation_fns.grid_search, verbosity=data[1])


     def test_minimise_argfail_args(self):
@@ -231,8 +231,8 @@
             self.assertRaises(RelaxBinError, self.minimisation_fns.minimise, 'Newton', scaling=data[1])


-    def test_minimise_argfail_print_flag(self):
-        """The print_flag arg test of the minimise() user function."""
+    def test_minimise_argfail_verbosity(self):
+        """The verbosity arg test of the minimise() user function."""

         # Loop over the data types.
         for data in DATA_TYPES:
@@ -241,6 +241,6 @@
                 continue

             # The argument test.
-            self.assertRaises(RelaxIntError, self.minimisation_fns.minimise, 'Newton', print_flag=data[1])
-
-
+            self.assertRaises(RelaxIntError, self.minimisation_fns.minimise, 'Newton', verbosity=data[1])
+
+


_______________________________________________
relax (http://nmr-relax.com)

This is the relax-commits mailing list
relax-commits@xxxxxxx

To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits


      
--
Sebastien Morin
Etudiant au PhD en biochimie
Laboratoire de resonance magnetique nucleaire
Dr Stephane Gagne
CREFSIP (Universite Laval, Quebec, CANADA)
1-418-656-2131 #4530



    

  

-- 
Sebastien Morin
Etudiant au PhD en biochimie
Laboratoire de resonance magnetique nucleaire
Dr Stephane Gagne
CREFSIP (Universite Laval, Quebec, CANADA)
1-418-656-2131 #4530

Related Messages


Powered by MHonArc, Updated Wed Jan 09 17:41:22 2008